==> nextcloud-30.0.15.tar.bz2: nextcloud/apps/theming/l10n/fr.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Le nom donné est trop long",
    "The given web address is too long" : "L’adresse web donnée est trop longue",
    "The given web address is not a valid URL" : "L'adresse web n'est pas une URL valide",
    "The given legal notice address is too long" : "L'adresse fournie pour la notice légale est trop longue",
    "The given legal notice address is not a valid URL" : "L'adresse de la notice légale n'est pas une URL valide",
    "The given privacy policy address is too long" : "L'adresse de la politique de confidentialité est trop longue",
    "The given privacy policy address is not a valid URL" : "L'adresse de la politique de confidentialité n'est pas une URL valide",
    "The given slogan is too long" : "Le slogan donné est trop long",
    "The given color is invalid" : "La couleur donnée est invalide",
    "Disable-user-theming should be true or false" : "Désactiver le thème de l'utilisateur doit valoir vrai ou faux.",
    "Saved" : "Enregistré",
    "Invalid app given" : "Application fournie non valide",
    "Invalid type for setting \"defaultApp\" given" : "Type non valide pour le paramètre \"defaultApp\" fourni",
    "Invalid setting key" : "Clé de paramétrage non valide",
    "The file was uploaded" : "Le fichier a été téléversé",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Le fichier téléversé dépasse la valeur upload_max_filesize située dans le fichier php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le fichier téléversé dépasse la valeur MAX_FILE_SIZE spécifiée dans le formulaire HTML",
    "The file was only partially uploaded" : "Le fichier n'a été que partiellement téléversé",
    "No file was uploaded" : "Aucun fichier n'a été téléversé",
    "Missing a temporary folder" : "Absence de dossier temporaire",
    "Could not write file to disk" : "Impossible d'écrire le fichier sur le disque",
    "A PHP extension stopped the file upload" : "Une extension PHP a arrêté le téléversement du fichier",
    "No file uploaded" : "Aucun fichier téléversé",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Vous utilisez déjà un thème personnalisé. Les paramètres de l'application Theming peuvent être remplacés par ceux-ci.",
    "Theming" : "Personnaliser l'apparence",
    "Appearance and accessibility" : "Apparence et accessibilité",
    "PHP Imagick module" : "Module PHP Imagick",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Le module PHP \"imagick\" n’est pas actif mais l’application Theming est activée. Pour que la génération du Favicon fonctionne correctement, ce module doit être installé et actif.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Le module PHP « imagick » n’a aucune prise en charge du SVG dans cette instance. Pour une meilleure compatibilité, il est recommandé de l’installer.",
    "Dark theme with high contrast mode" : "Thème sombre avec mode de contraste élevé",
    "Enable dark high contrast mode" : "Activer le mode sombre à contraste élevé",
    "Similar to the high contrast mode, but with dark colours." : "Similaire au mode de contraste élevé, mais avec des couleurs sombres.",
    "Dark theme" : "Thème sombre",
    "Enable dark theme" : "Activer le thème sombre",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Un thème sombre pour soulager vos yeux en réduisant la luminosité et l'éclat général.",
    "System default theme" : "Thème par défaut du système",
    "Enable the system default" : "Activer le thème par défaut du système",
    "Using the default system appearance." : "Utiliser l'apparence par défaut du système.",
    "Dyslexia font" : "Police pour dyslexiques",
    "Enable dyslexia font" : "Activer la police pour dyslexiques",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic est une police de caractères libre conçue pour atténuer certaines des erreurs de lecture courantes causées par la dyslexie.",
    "High contrast mode" : "Thème à contraste élevé",
    "Enable high contrast mode" : "Activer le thème à contraste élevé",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un thème au contraste élevé pour faciliter votre navigation. La qualité visuelle sera réduite, mais la clarté sera accrue.",
    "Light theme" : "Thème clair",
    "Enable the default light theme" : "Activer le thème clair par défaut",
    "The default light appearance." : "L'apparence claire par défaut.",
    "Legal notice" : "Notice légale",
    "Privacy policy" : "Politique de confidentialité",
    "Adjust the Nextcloud theme" : "Modifier le thème Nextcloud",
    "Name" : "Nom",
    "Web link" : "Lien web",
    "a safe home for all your data" : "un lieu sûr pour toutes vos données",
    "Slogan" : "Slogan",
    "Primary color" : "Couleur principale",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "La couleur principale est utilisée pour mettre en évidence des éléments tels que les boutons importants. Elle peut être légèrement modifiée en fonction du schéma de couleurs actuel.",
    "Legal notice link" : "Lien vers la notice légale",
    "Privacy policy link" : "Lien vers la politique de confidentialité",
    "Header logo" : "Logo d'en-tête",
    "Upload new header logo" : "Téléverser un nouveau logo d'en-tête",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Téléverser un nouveau favicon",
    "User settings" : "Paramètres utilisateurs",
    "Disable user theming" : "Désactiver la gestion du thème par l'utilisateur",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Bien que vous puissiez sélectionner et personnaliser votre instance, les utilisateurs peuvent modifier leur arrière-plan et leurs couleurs. Si vous voulez imposer votre personnalisation, vous pouvez activer cette option.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Cette extension permet de personnaliser facilement l'apparence de votre instance et des clients supportés. La personnalisation de l'apparence sera visible par tous les utilisateurs.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Au lieu d'une image d'arrière-plan, vous pouvez également définir une couleur unie d'arrière-plan. Si vous utilisez une image d'arrière-plan, la modification de cette couleur influencera la couleur des icônes du menu de l'application.",
    "Background color" : "Couleur d'arrière-plan",
    "Upload new logo" : "Téléverser un nouveau logo",
    "Logo" : "Logo",
    "Upload new background and login image" : "Téléverser une nouvelle image d'arrière-plan et de connexion",
    "Background and login image" : "Image d'arrière-plan et de connexion",
    "Advanced options" : "Options avancées",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installez l'extension PHP ImageMagick qui prend en charge les images SVG pour générer automatiquement des favicons à partir du logo téléversé et de la couleur indiquée.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L’accès universel est très important pour nous. Nous suivons les standards du web et nous assurons que tout soit également utilisable sans souris et avec des logiciels d’assistance technique tels que les lecteurs d’écran. Nous visons à respecter les {linkstart}Règles pour l’accessibilité des contenus Web{linkend} 2.1 de niveau AA et même de niveau AAA avec le thème à fort contraste.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si vous rencontrez des problèmes, n'hésitez pas à les signaler sur {issuetracker}notre outil de suivi des problèmes{linkend}. Et si vous voulez vous impliquer, venez rejoindre {designteam}notre équipe de design{linkend} !",
    "Unable to apply the setting." : "Impossible d'appliquer le réglage.",
    "Appearance and accessibility settings" : "Paramètres d’apparence et d’accessibilité",
    "Misc accessibility options" : "Diverses options d'accessibilité",
    "Enable blur background filter (may increase GPU load)" : "Activer le filtre flou de l'arrière-plan (peut augmenter la charge du GPU)",
    "Customization has been disabled by your administrator" : "La personnalisation a été désactivée par votre administrateur",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Définissez une couleur principale pour mettre en évidence les éléments importants. La couleur utilisée pour les éléments tels que les boutons primaires peut varier légèrement en fonction des exigences d'accessibilité.",
    "Background and color" : "Arrière-plan et couleur",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "L'arrière-plan peut être une image du catalogue par défaut, une image personnalisée téléversée ou une couleur unie.",
    "Keyboard shortcuts" : "Raccourcis clavier",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Dans certains cas, les raccourcis clavier peuvent interférer avec les outils d'accessibilité. Afin de vous permettre de vous concentrer correctement sur votre outil, vous pouvez désactiver tous les raccourcis clavier ici. Cela désactivera également tous les raccourcis disponibles dans les applications.",
    "Disable all keyboard shortcuts" : "Désactiver tous les raccourcis clavier",
    "Current selected app: {app}, position {position} of {total}" : "L'application sélectionnée actuelle : {app}, position {position} sur {total}",
    "Move up" : "Déplacer vers le haut",
    "Move down" : "Déplacer vers le bas",
    "Select a background from your files" : "Sélectionner un arrière-plan parmi vos fichiers",
    "Select background" : "Sélectionner un arrière-plan",
    "No background has been selected" : "Aucun arrière-plan n'a été sélectionné",
    "Custom background" : "Arrière-plan personnalisé",
    "Plain background" : "Arrière-plan uni",
    "Default background" : "Arrière-plan par défaut",
    "Theme selection is enforced" : "La sélection du thème est imposée",
    "Could not set the app order" : "Impossible de définir l'ordre des applications",
    "Could not reset the app order" : "Impossible de réinitialiser l'ordre des applications",
    "Navigation bar settings" : "Paramètres de la barre de navigation",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Vous pouvez configurer l'ordre des applications utilisées dans la barre de navigation. La première entrée sera l'application par défaut, ouverte après la connexion ou en cliquant sur le logo.",
    "The default app can not be changed because it was configured by the administrator." : "L'application par défaut ne peut pas être changée, car elle a été configurée par l'administrateur.",
    "The app order was changed, to see it in action you have to reload the page." : "L'ordre des applications a été changé, pour le voir en action, vous devez recharger la page.",
    "Reset default app order" : "Rétablir l'ordre par défaut des applications ",
    "Could not set primary color" : "Impossible de définir la couleur principale",
    "Reset primary color" : "Réinitialiser la couleur principale",
    "Could not set global default apps" : "Impossible de définir les applications globales par défaut",
    "Default app" : "Application par défaut",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "L'application par défaut est l'application qui, par exemple, s'ouvre après une connexion ou lorsque l'on clique sur le logo du menu.",
    "Use custom default app" : "Utiliser l'application par défaut personnalisée",
    "Global default app" : "Application globale par défaut",
    "Global default apps" : "Applications globales par défaut",
    "Default app priority" : "Priorité de l'application par défaut",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Si une application n'est pas activée pour un utilisateur, l'application suivante avec une priorité plus basse sera utilisée.",
    "Select a custom color" : "Sélectionnez une couleur personnalisée",
    "Reset to default" : "Restaurer les valeurs par défaut",
    "Upload" : "Téléverser",
    "Remove background image" : "Retirer l'image d'arrière-plan",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accès universel est très important pour nous. Nous suivons les standards du web et nous vérifions que tout est utilisable même sans souris et sans logiciel d'assistance comme les lecteurs d'écran. Nous visons à respecter les {guidelines}Règles pour l'accessibilité des contenus Web{linkend} 2.1 de niveau AA et même de niveau AAA avec le thème à fort contraste.",
    ". Unable to apply the setting." : ". Impossible d'appliquer le réglage."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.13.tar.bz2: nextcloud/apps/theming/l10n/fr.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Le nom donné est trop long",
    "The given web address is too long" : "L’adresse web donnée est trop longue",
    "The given web address is not a valid URL" : "L'adresse web n'est pas une URL valide",
    "The given legal notice address is too long" : "L'adresse fournie pour la notice légale est trop longue",
    "The given legal notice address is not a valid URL" : "L'adresse de la notice légale n'est pas une URL valide",
    "The given privacy policy address is too long" : "L'adresse de la politique de confidentialité est trop longue",
    "The given privacy policy address is not a valid URL" : "L'adresse de la politique de confidentialité n'est pas une URL valide",
    "The given slogan is too long" : "Le slogan donné est trop long",
    "The given color is invalid" : "La couleur donnée est invalide",
    "Invalid setting key" : "Clé de paramétrage non valide",
    "Saved" : "Enregistré",
    "Invalid app given" : "Application fournie non valide",
    "Invalid type for setting \"defaultApp\" given" : "Type non valide pour le paramètre \"defaultApp\" fourni",
    "The file was uploaded" : "Le fichier a été téléversé",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Le fichier téléversé dépasse la valeur upload_max_filesize située dans le fichier php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le fichier téléversé dépasse la valeur MAX_FILE_SIZE spécifiée dans le formulaire HTML",
    "The file was only partially uploaded" : "Le fichier n'a été que partiellement téléversé",
    "No file was uploaded" : "Aucun fichier n'a été téléversé",
    "Missing a temporary folder" : "Absence de dossier temporaire",
    "Could not write file to disk" : "Impossible d'écrire le fichier sur le disque",
    "A PHP extension stopped the file upload" : "Une extension PHP a arrêté le téléversement du fichier",
    "No file uploaded" : "Aucun fichier téléversé",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Vous utilisez déjà un thème personnalisé. Les paramètres de l'application Theming peuvent être remplacés par ceux-ci.",
    "Theming" : "Personnaliser l'apparence",
    "Appearance and accessibility" : "Apparence et accessibilité",
    "PHP Imagick module" : "Module PHP Imagick",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Le module PHP \"imagick\" n’est pas actif mais l’application Theming est activée. Pour que la génération du Favicon fonctionne correctement, ce module doit être installé et actif.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Le module PHP « imagick » n’a aucune prise en charge du SVG dans cette instance. Pour une meilleure compatibilité, il est recommandé de l’installer.",
    "Dark theme with high contrast mode" : "Thème sombre avec mode de contraste élevé",
    "Enable dark high contrast mode" : "Activer le mode sombre à contraste élevé",
    "Similar to the high contrast mode, but with dark colours." : "Similaire au mode de contraste élevé, mais avec des couleurs sombres.",
    "Dark theme" : "Thème sombre",
    "Enable dark theme" : "Activer le thème sombre",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Un thème sombre pour soulager vos yeux en réduisant la luminosité et l'éclat général.",
    "System default theme" : "Thème par défaut du système",
    "Enable the system default" : "Activer le thème par défaut du système",
    "Using the default system appearance." : "Utiliser l'apparence par défaut du système.",
    "Dyslexia font" : "Police pour dyslexiques",
    "Enable dyslexia font" : "Activer la police pour dyslexiques",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic est une police de caractères libre conçue pour atténuer certaines des erreurs de lecture courantes causées par la dyslexie.",
    "High contrast mode" : "Thème à contraste élevé",
    "Enable high contrast mode" : "Activer le thème à contraste élevé",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un thème au contraste élevé pour faciliter votre navigation. La qualité visuelle sera réduite, mais la clarté sera accrue.",
    "Light theme" : "Thème clair",
    "Enable the default light theme" : "Activer le thème clair par défaut",
    "The default light appearance." : "L'apparence claire par défaut.",
    "Legal notice" : "Notice légale",
    "Privacy policy" : "Politique de confidentialité",
    "Adjust the Nextcloud theme" : "Modifier le thème Nextcloud",
    "Could not set global default apps" : "Impossible de définir les applications globales par défaut",
    "Navigation bar settings" : "Paramètres de la barre de navigation",
    "Default app" : "Application par défaut",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "L'application par défaut est l'application qui, par exemple, s'ouvre après une connexion ou lorsque l'on clique sur le logo du menu.",
    "Use custom default app" : "Utiliser l'application par défaut personnalisée",
    "Global default app" : "Application globale par défaut",
    "Global default apps" : "Applications globales par défaut",
    "Default app priority" : "Priorité de l'application par défaut",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Si une application n'est pas activée pour un utilisateur, l'application suivante avec une priorité plus basse sera utilisée.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Cette extension permet de personnaliser facilement l'apparence de votre instance et des clients supportés. La personnalisation de l'apparence sera visible par tous les utilisateurs.",
    "Name" : "Nom",
    "Web link" : "Lien web",
    "Slogan" : "Slogan",
    "a safe home for all your data" : "un lieu sûr pour toutes vos données",
    "Legal notice link" : "Lien vers la notice légale",
    "Privacy policy link" : "Lien vers la politique de confidentialité",
    "Background and color" : "Arrière-plan et couleur",
    "Primary color" : "Couleur principale",
    "Background color" : "Couleur d'arrière-plan",
    "Remove background image" : "Retirer l'image d'arrière-plan",
    "Background image" : "Image d'arrière-plan",
    "Favicon" : "Favicon",
    "Logo" : "Logo",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Bien que vous puissiez sélectionner et personnaliser votre instance, les utilisateurs peuvent modifier leur arrière-plan et leurs couleurs. Si vous voulez imposer votre personnalisation, vous pouvez activer cette option.",
    "Disable user theming" : "Désactiver la gestion du thème par l'utilisateur",
    "Current selected app: {app}, position {position} of {total}" : "L'application sélectionnée actuelle : {app}, position {position} sur {total}",
    "Move up" : "Déplacer vers le haut",
    "Move down" : "Déplacer vers le bas",
    "Theme selection is enforced" : "La sélection du thème est imposée",
    "Could not set the app order" : "Impossible de définir l'ordre des applications",
    "Could not reset the app order" : "Impossible de réinitialiser l'ordre des applications",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Vous pouvez configurer l'ordre des applications utilisées dans la barre de navigation. La première entrée sera l'application par défaut, ouverte après la connexion ou en cliquant sur le logo.",
    "The default app can not be changed because it was configured by the administrator." : "L'application par défaut ne peut pas être changée, car elle a été configurée par l'administrateur.",
    "The app order was changed, to see it in action you have to reload the page." : "L'ordre des applications a été changé, pour le voir en action, vous devez recharger la page.",
    "Reset default app order" : "Rétablir l'ordre par défaut des applications ",
    "Select a background from your files" : "Sélectionner un arrière-plan parmi vos fichiers",
    "Select background" : "Sélectionner un arrière-plan",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "L'arrière-plan peut être une image du catalogue par défaut, une image personnalisée téléversée ou une couleur unie.",
    "Custom background" : "Arrière-plan personnalisé",
    "Plain background" : "Arrière-plan uni",
    "Default background" : "Arrière-plan par défaut",
    "Keyboard shortcuts" : "Raccourcis clavier",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Dans certains cas, les raccourcis clavier peuvent interférer avec les outils d'accessibilité. Afin de vous permettre de vous concentrer correctement sur votre outil, vous pouvez désactiver tous les raccourcis clavier ici. Cela désactivera également tous les raccourcis disponibles dans les applications.",
    "Disable all keyboard shortcuts" : "Désactiver tous les raccourcis clavier",
    "Could not set primary color" : "Impossible de définir la couleur principale",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Définissez une couleur principale pour mettre en évidence les éléments importants. La couleur utilisée pour les éléments tels que les boutons primaires peut varier légèrement en fonction des exigences d'accessibilité.",
    "Reset primary color" : "Réinitialiser la couleur principale",
    "Reset to default" : "Restaurer les valeurs par défaut",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L’accès universel est très important pour nous. Nous suivons les standards du web et nous assurons que tout soit également utilisable sans souris et avec des logiciels d’assistance technique tels que les lecteurs d’écran. Nous visons à respecter les {linkstart}Règles pour l’accessibilité des contenus Web{linkend} 2.1 de niveau AA et même de niveau AAA avec le thème à fort contraste.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si vous rencontrez des problèmes, n'hésitez pas à les signaler sur {issuetracker}notre outil de suivi des problèmes{linkend}. Et si vous voulez vous impliquer, venez rejoindre {designteam}notre équipe de design{linkend} !",
    "Unable to apply the setting." : "Impossible d'appliquer le réglage.",
    "Appearance and accessibility settings" : "Paramètres d’apparence et d’accessibilité",
    "Misc accessibility options" : "Diverses options d'accessibilité",
    "Enable blur background filter (may increase GPU load)" : "Activer le filtre flou de l'arrière-plan (peut augmenter la charge du GPU)",
    "Customization has been disabled by your administrator" : "La personnalisation a été désactivée par votre administrateur",
    "Disable-user-theming should be true or false" : "Désactiver le thème de l'utilisateur doit valoir vrai ou faux.",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "La couleur principale est utilisée pour mettre en évidence des éléments tels que les boutons importants. Elle peut être légèrement modifiée en fonction du schéma de couleurs actuel.",
    "Header logo" : "Logo d'en-tête",
    "Upload new header logo" : "Téléverser un nouveau logo d'en-tête",
    "Upload new favicon" : "Téléverser un nouveau favicon",
    "User settings" : "Paramètres utilisateurs",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Au lieu d'une image d'arrière-plan, vous pouvez également définir une couleur unie d'arrière-plan. Si vous utilisez une image d'arrière-plan, la modification de cette couleur influencera la couleur des icônes du menu de l'application.",
    "Upload new logo" : "Téléverser un nouveau logo",
    "Upload new background and login image" : "Téléverser une nouvelle image d'arrière-plan et de connexion",
    "Background and login image" : "Image d'arrière-plan et de connexion",
    "Advanced options" : "Options avancées",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installez l'extension PHP ImageMagick qui prend en charge les images SVG pour générer automatiquement des favicons à partir du logo téléversé et de la couleur indiquée.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L'accès universel est très important pour nous. Nous suivons les standards du web et nous vérifions que tout est utilisable même sans souris et sans logiciel d'assistance comme les lecteurs d'écran. Nous visons à respecter les {guidelines}Règles pour l'accessibilité des contenus Web{linkend} 2.1 de niveau AA et même de niveau AAA avec le thème à fort contraste.",
    ". Unable to apply the setting." : ". Impossible d'appliquer le réglage.",
    "No background has been selected" : "Aucun arrière-plan n'a été sélectionné",
    "Select a custom color" : "Sélectionnez une couleur personnalisée",
    "Upload" : "Téléverser"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
